@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Software::License::SSLeay;
-$Software::License::SSLeay::VERSION = '0.103009';
+$Software::License::SSLeay::VERSION = '0.103014';
 use parent 'Software::License';
 # ABSTRACT: The Original SSLeay License
 
@@ -9,6 +9,7 @@ sub name { 'Original SSLeay License' }
 sub url  { 'http://h71000.www7.hp.com/doc/83final/BA554_90007/apcs02.html' }
 sub meta_name  { 'unrestricted' }
 sub meta2_name { 'ssleay' }
+sub spdx_expression  { 'SSLeay' }
 
 1;
 
@@ -22,7 +23,7 @@ Software::License::SSLeay - The Original SSLeay License
 
 =head1 VERSION
 
-version 0.103009
+version 0.103014
 
 =head1 AUTHOR
 
@@ -30,7 +31,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo Signes.
+This software is copyright (c) 2018 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -51,7 +52,7 @@ __LICENSE__
   included with this distribution is covered by the same copyright terms
   except that the holder is Tim Hudson (tjh@cryptsoft.com).
 
-  Copyright remains Eric Youngâs, and as such any Copyright notices in the code
+  Copyright remains Eric Young’s, and as such any Copyright notices in the code
   are not to be removed. If this package is used in a product, Eric Young
   should be given attribution as the author of the parts of the library used.
   This can be in the form of a textual message at program startup or in
@@ -67,16 +68,16 @@ __LICENSE__
        documentation and/or other materials provided with the distribution.
     3. All advertising materials mentioning features or use of this software
        must display the following acknowledgement:
-       âThis product includes cryptographic software written by
-        Eric Young (eay@cryptsoft.com)â
-       The word âcryptographicâ can be left out if the rouines from the library
+       “This product includes cryptographic software written by
+        Eric Young (eay@cryptsoft.com)”
+       The word ‘cryptographic’ can be left out if the rouines from the library
        being used are not cryptographic related :-).
     4. If you include any Windows specific code (or a derivative thereof) from
        the apps directory (application code) you must include an
-       acknowledgement: âThis product includes software written by Tim Hudson
-       (tjh@cryptsoft.com)â
+       acknowledgement: “This product includes software written by Tim Hudson
+       (tjh@cryptsoft.com)”
 
-  THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ââAS ISââ AND
+  THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ‘‘AS IS’’ AND
   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
